==> schedulerx2-worker-1.2.3-sources.jar: com/alibaba/schedulerx/worker/util/ContanerUtil.java <==
package com.alibaba.schedulerx.worker.util;

import java.io.IOException;
import java.util.List;

import com.alibaba.schedulerx.common.domain.JobInstanceData;
import com.alibaba.schedulerx.common.util.HessianUtil;
import com.alibaba.schedulerx.protocol.Common.UpstreamData;
import com.alibaba.schedulerx.protocol.Worker.MasterStartContainerRequest;
import com.alibaba.schedulerx.worker.domain.JobContext;
import com.alibaba.schedulerx.worker.domain.ShardingTask;

import com.google.common.collect.Lists;
import org.joda.time.DateTime;

/**
 *
 * @author xiaomeng.hxm
 */
public class ContanerUtil {

    public static JobContext convert2JobContext(MasterStartContainerRequest request) throws IOException {
        JobContext.JobContextBuilder contextBuilder = JobContext.newBuilder();
        contextBuilder.setJobId(request.getJobId());
        contextBuilder.setJobInstanceId(request.getJobInstanceId());
        contextBuilder.setTaskId(request.getTaskId());
        contextBuilder.setScheduleTime(new DateTime(request.getScheduleTime()));
        contextBuilder.setDataTime(new DateTime(request.getDataTime()));
        contextBuilder.setExecuteMode(request.getExecuteMode());
        contextBuilder.setJobType(request.getJobType());
        contextBuilder.setContent(request.getContent());
        contextBuilder.setJobParameters(request.getParameters());
        contextBuilder.setInstanceParameters(request.getInstanceParameters());
        contextBuilder.setUser(request.getUser());
        contextBuilder.setTaskMasterActorPath(request.getInstanceMasterAkkaPath());
        contextBuilder.setGroupId(request.getGroupId());
        contextBuilder.setMaxAttempt(request.getMaxAttempt());
        contextBuilder.setAttempt(request.getAttempt());
        if (request.hasTaskName()) {
            contextBuilder.setTaskName(request.getTaskName());
        }
        if (request.hasTask()) {
            Object obj = HessianUtil.toObject(request.getTask().toByteArray());
            contextBuilder.setTask(obj);
            // 如果是分片task，设置分片id和分片参数
            if (obj instanceof ShardingTask) {
                ShardingTask shardingTask = (ShardingTask)obj;
                contextBuilder.setShardingId(shardingTask.getId());
                contextBuilder.setShardingParameter(shardingTask.getParameter());
            }
        }
        if (request.hasTaskMaxAttempt()) {
            contextBuilder.setTaskMaxAttempt(request.getTaskMaxAttempt());
        }
        if (request.hasTaskAttemptInterval()) {
            contextBuilder.setTaskAttemptInterval(request.getTaskAttemptInterval());
        }
        List<UpstreamData> upstreamProtoDatas = request.getUpstreamDataList();
        List<JobInstanceData> upstreamDatas = Lists.newArrayList();
        for (UpstreamData upstreamData : upstreamProtoDatas) {
            upstreamDatas.add(new JobInstanceData(upstreamData.getJobName(), upstreamData.getData()));
        }
        contextBuilder.setUpstreamData(upstreamDatas);
        if (request.hasWfInstanceId()) {
            contextBuilder.setWfInstanceId(request.getWfInstanceId());
        }
        if (request.hasSerialNum()) {
            contextBuilder.setSerialNum(request.getSerialNum());
        }
        if (request.hasJobName()) {
            contextBuilder.setJobName(request.getJobName());
        }
        return contextBuilder.build();
    }
}

==> schedulerx2-worker-1.3.3-sources.jar: com/alibaba/schedulerx/worker/util/ContanerUtil.java <==
package com.alibaba.schedulerx.worker.util;

import java.io.IOException;
import java.util.List;

import com.alibaba.schedulerx.common.domain.JobInstanceData;
import com.alibaba.schedulerx.common.util.HessianUtil;
import com.alibaba.schedulerx.protocol.Common.UpstreamData;
import com.alibaba.schedulerx.protocol.Worker.MasterStartContainerRequest;
import com.alibaba.schedulerx.worker.domain.JobContext;
import com.alibaba.schedulerx.worker.domain.ShardingTask;

import com.google.common.collect.Lists;
import org.joda.time.DateTime;

/**
 *
 * @author xiaomeng.hxm
 */
public class ContanerUtil {

    public static JobContext convert2JobContext(MasterStartContainerRequest request) throws IOException {
        JobContext.JobContextBuilder contextBuilder = JobContext.newBuilder();
        contextBuilder.setJobId(request.getJobId());
        contextBuilder.setJobInstanceId(request.getJobInstanceId());
        contextBuilder.setTaskId(request.getTaskId());
        contextBuilder.setScheduleTime(new DateTime(request.getScheduleTime()));
        contextBuilder.setDataTime(new DateTime(request.getDataTime()));
        contextBuilder.setExecuteMode(request.getExecuteMode());
        contextBuilder.setJobType(request.getJobType());
        contextBuilder.setContent(request.getContent());
        contextBuilder.setJobParameters(request.getParameters());
        contextBuilder.setInstanceParameters(request.getInstanceParameters());
        contextBuilder.setUser(request.getUser());
        contextBuilder.setTaskMasterActorPath(request.getInstanceMasterAkkaPath());
        contextBuilder.setGroupId(request.getGroupId());
        contextBuilder.setMaxAttempt(request.getMaxAttempt());
        contextBuilder.setAttempt(request.getAttempt());
        if (request.hasTaskName()) {
            contextBuilder.setTaskName(request.getTaskName());
        }
        if (request.hasTask()) {
            Object obj = HessianUtil.toObject(request.getTask().toByteArray());
            contextBuilder.setTask(obj);
            // 如果是分片task，设置分片id和分片参数
            if (obj instanceof ShardingTask) {
                ShardingTask shardingTask = (ShardingTask)obj;
                contextBuilder.setShardingId(shardingTask.getId());
                contextBuilder.setShardingParameter(shardingTask.getParameter());
            }
        } else {
            contextBuilder.setShardingId(request.getTaskId());
        }
        if (request.hasTaskMaxAttempt()) {
            contextBuilder.setTaskMaxAttempt(request.getTaskMaxAttempt());
        }
        if (request.hasTaskAttemptInterval()) {
            contextBuilder.setTaskAttemptInterval(request.getTaskAttemptInterval());
        }
        List<UpstreamData> upstreamProtoDatas = request.getUpstreamDataList();
        List<JobInstanceData> upstreamDatas = Lists.newArrayList();
        for (UpstreamData upstreamData : upstreamProtoDatas) {
            upstreamDatas.add(new JobInstanceData(upstreamData.getJobName(), upstreamData.getData()));
        }
        contextBuilder.setUpstreamData(upstreamDatas);
        if (request.hasWfInstanceId()) {
            contextBuilder.setWfInstanceId(request.getWfInstanceId());
        }
        if (request.hasSerialNum()) {
            contextBuilder.setSerialNum(request.getSerialNum());
        }
        if (request.hasJobName()) {
            contextBuilder.setJobName(request.getJobName());
        }
        if (request.hasShardingNum()) {
            contextBuilder.setShardingNum(request.getShardingNum());
        }
        return contextBuilder.build();
    }
}
